package com.fs.live.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.live.domain.LiveGoodsOrderItems;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 订单商品Mapper接口
 *
 * @author fs
 * @date 2025-01-17
 */
public interface LiveGoodsOrderItemsMapper extends BaseMapper<LiveGoodsOrderItems>
{
    /**
     * 查询订单商品
     *
     * @param id 订单商品主键
     * @return 订单商品
     */
    public LiveGoodsOrderItems selectLiveGoodsOrderItemsById(Long id);

    /**
     * 查询企业订单商品
     * @param id            订单ID
     * @param companyId     企业ID
     * @param companyUserId 企业用户ID
     * @return LiveGoodsOrderItems
     */
    LiveGoodsOrderItems selectLiveGoodsOrderItemsByIdAndCompanyIdAndCompanyUserId(@Param("id") Long id, @Param("companyId") Long companyId, @Param("companyUserId") Long companyUserId);

    /**
     * 查询订单商品列表
     *
     * @param liveGoodsOrderItems 订单商品
     * @return 订单商品集合
     */
    public List<LiveGoodsOrderItems> selectLiveGoodsOrderItemsList(LiveGoodsOrderItems liveGoodsOrderItems);

    /**
     * 新增订单商品
     *
     * @param liveGoodsOrderItems 订单商品
     * @return 结果
     */
    public int insertLiveGoodsOrderItems(LiveGoodsOrderItems liveGoodsOrderItems);

    /**
     * 修改订单商品
     *
     * @param liveGoodsOrderItems 订单商品
     * @return 结果
     */
    public int updateLiveGoodsOrderItems(LiveGoodsOrderItems liveGoodsOrderItems);

    /**
     * 删除订单商品
     *
     * @param id 订单商品主键
     * @return 结果
     */
    public int deleteLiveGoodsOrderItemsById(Long id);

    /**
     * 批量删除订单商品
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLiveGoodsOrderItemsByIds(Long[] ids);
}
