package com.fs.live.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveWatchConfigMapper;
import com.fs.live.domain.LiveWatchConfig;
import com.fs.live.service.ILiveWatchConfigService;

/**
 * 直播观看奖励设置Service业务层处理
 *
 * @author fs
 * @date 2025-07-08
 */
@Service
public class LiveWatchConfigServiceImpl extends ServiceImpl<LiveWatchConfigMapper, LiveWatchConfig> implements ILiveWatchConfigService {

    /**
     * 查询直播观看奖励设置
     *
     * @param id 直播观看奖励设置主键
     * @return 直播观看奖励设置
     */
    @Override
    public LiveWatchConfig selectLiveWatchConfigById(Long id)
    {
        return baseMapper.selectLiveWatchConfigById(id);
    }

    /**
     * 查询直播观看奖励设置列表
     *
     * @param liveWatchConfig 直播观看奖励设置
     * @return 直播观看奖励设置
     */
    @Override
    public List<LiveWatchConfig> selectLiveWatchConfigList(LiveWatchConfig liveWatchConfig)
    {
        return baseMapper.selectLiveWatchConfigList(liveWatchConfig);
    }

    /**
     * 新增直播观看奖励设置
     *
     * @param liveWatchConfig 直播观看奖励设置
     * @return 结果
     */
    @Override
    public int insertLiveWatchConfig(LiveWatchConfig liveWatchConfig)
    {
        liveWatchConfig.setCreateTime(DateUtils.getNowDate());

        return baseMapper.insertLiveWatchConfig(liveWatchConfig);
    }

    /**
     * 修改直播观看奖励设置
     *
     * @param liveWatchConfig 直播观看奖励设置
     * @return 结果
     */
    @Override
    public int updateLiveWatchConfig(LiveWatchConfig liveWatchConfig)
    {
        liveWatchConfig.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateLiveWatchConfig(liveWatchConfig);
    }

    /**
     * 批量删除直播观看奖励设置
     *
     * @param ids 需要删除的直播观看奖励设置主键
     * @return 结果
     */
    @Override
    public int deleteLiveWatchConfigByIds(Long[] ids)
    {
        return baseMapper.deleteLiveWatchConfigByIds(ids);
    }

    /**
     * 删除直播观看奖励设置信息
     *
     * @param id 直播观看奖励设置主键
     * @return 结果
     */
    @Override
    public int deleteLiveWatchConfigById(Long id)
    {
        return baseMapper.deleteLiveWatchConfigById(id);
    }
}
